"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const asyncFilter_1 = require("./asyncFilter");
async function asyncFunc(item) {
    return await new Promise((resolve) => {
        resolve(item.id === 2);
    });
}
describe("filter", () => {
    it("filter with async function", async () => {
        const array = [
            {
                id: 1,
                a: false
            },
            {
                id: 2,
                a: false
            },
            {
                id: 3,
                a: true
            }
        ];
        const result = await asyncFilter_1.asyncFilter(array, asyncFunc);
        chai_1.expect(result).to.eql([
            {
                id: 2,
                a: false
            }
        ]);
    });
    it("filter with string shorthand", async () => {
        const array = [
            {
                id: 1,
                a: false
            },
            {
                id: 2,
                a: false
            },
            {
                id: 3,
                a: true
            }
        ];
        chai_1.expect(await asyncFilter_1.asyncFilter(array, "a")).to.eql([
            {
                id: 3,
                a: true
            }
        ]);
    });
    it("filter with object shorthand", async () => {
        const array = [
            {
                id: 1,
                a: false
            },
            {
                id: 2,
                a: false
            },
            {
                id: 3,
                a: true
            },
            {
                id: 2,
                a: true,
                foobar: "bar"
            }
        ];
        const result = await asyncFilter_1.asyncFilter(array, {
            id: 2,
            a: true
        });
        chai_1.expect(result).to.eql([
            {
                id: 2,
                a: true,
                foobar: "bar"
            }
        ]);
    });
});
//# sourceMappingURL=asyncFilter.spec.js.map