"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const asyncFind_1 = require("./asyncFind");
async function asyncFunc(item) {
    return await new Promise((resolve) => {
        resolve(item.id === 2);
    });
}
describe("find", () => {
    it("find with async function", async () => {
        const array = [
            {
                id: 1,
                a: false
            },
            {
                id: 2,
                a: false
            },
            {
                id: 3,
                a: true
            }
        ];
        const result = await asyncFind_1.asyncFind(array, asyncFunc);
        chai_1.expect(result).to.eql({
            id: 2,
            a: false
        });
    });
    it("find with string shorthand", async () => {
        const array = [
            {
                id: 1,
                a: false
            },
            {
                id: 2,
                a: false
            },
            {
                id: 3,
                a: true
            }
        ];
        chai_1.expect(await asyncFind_1.asyncFind(array, "a")).to.eql({
            id: 3,
            a: true
        });
    });
    it("find with object shorthand", async () => {
        const array = [
            {
                id: 1,
                a: false
            },
            {
                id: 2,
                a: false
            },
            {
                id: 3,
                a: true
            },
            {
                id: 2,
                a: true,
                foobar: "bar"
            }
        ];
        const result = await asyncFind_1.asyncFind(array, {
            id: 2,
            a: true
        });
        chai_1.expect(result).to.eql({
            id: 2,
            a: true,
            foobar: "bar"
        });
    });
});
//# sourceMappingURL=asyncFind.spec.js.map